@@ -10,7 +10,9 @@ use warnings;
 use Scalar::Util qw[ blessed ];
 use MRO::Compat;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
+
+use Hash::Wrap::Class;
 
 our @EXPORT = qw[ wrap_hash ];
 
@@ -126,10 +128,9 @@ sub import {
 sub _wrap_hash ($) { ## no critic (ProhibitSubroutinePrototypes)
     my $hash = shift;
 
-    if ( ! 'HASH' eq ref $hash ) {
-        require Carp;
-        croak( "argument to wrap_hash must be a hashref\n" );
-    }
+    _croak( "argument to wrap_hash must be a hashref\n" )
+      unless 'HASH' eq ref $hash;
+
     bless $hash, 'Hash::Wrap::Class';
 }
 
@@ -263,7 +264,7 @@ Hash::Wrap - create lightweight on-the-fly objects from hashes
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -366,13 +367,16 @@ is used. If a coderef, it will be called as
 
 By default, the object uses the hash directly.
 
-=item C<lvalue> => I<boolean>
+=item C<-lvalue> => I<boolean>
 
 If true, the accessors will be lvalue routines, e.g. they can
 change the underlying hash value by assigning to them:
 
    $obj->attr = 3;
 
+The hash entry must already exist before using the accessor in
+this manner, or it will throw an exception.
+
 This is only available on Perl 5.16 and higher.
 
 =back
@@ -703,15 +707,17 @@ __END__
 #pod
 #pod By default, the object uses the hash directly.
 #pod
-#pod =item C<lvalue> => I<boolean>
+#pod =item C<-lvalue> => I<boolean>
 #pod
 #pod If true, the accessors will be lvalue routines, e.g. they can
 #pod change the underlying hash value by assigning to them:
 #pod
 #pod    $obj->attr = 3;
 #pod
-#pod This is only available on Perl 5.16 and higher.
+#pod The hash entry must already exist before using the accessor in
+#pod this manner, or it will throw an exception.
 #pod
+#pod This is only available on Perl 5.16 and higher.
 #pod
 #pod =back
 #pod
